<!DOCTYPE html>


<h2>Web Robot</h2>

<h1></h1>


<p>You can use this framework to create digital robots for webApps.</p>

<h1></h1>


<p>You can contact: david.johnnes@gmail.com  'for support'.</p>

<h1></h1>


